(api-interface)=

# Interface

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: module.rst
   :recursive:

   crowsetta.interface
```

## Base

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: class.rst

   crowsetta.interface.base.BaseFormat
```

## Sequence-Like

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: class.rst

   crowsetta.interface.seq.SeqLike
```

## Bounding Box-Like

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: class.rst

   crowsetta.interface.bbox.BBoxLike
```
